Index: pkg/analysis_server/lib/analysis/navigation/navigation_core.dart |
diff --git a/pkg/analysis_server/lib/analysis/navigation/navigation_core.dart b/pkg/analysis_server/lib/analysis/navigation/navigation_core.dart |
index c708d9a85dc294f10afebbc4a782c80f7edf47e9..e8566f46b391445ea341f61ab4c96c2d1a4022fa 100644 |
--- a/pkg/analysis_server/lib/analysis/navigation/navigation_core.dart |
+++ b/pkg/analysis_server/lib/analysis/navigation/navigation_core.dart |
@@ -17,10 +17,10 @@ import 'package:analyzer/src/generated/source.dart' show Source; |
abstract class NavigationContributor { |
/** |
* Contribute navigation regions for a part of the given [source] into the |
* given [holder]. The part is specified by the [offset] and [length]. |
* The [context] can be used to get analysis results. |
*/ |
- void computeNavigation(NavigationHolder holder, AnalysisContext context, |
+ void computeNavigation(NavigationCollector collector, AnalysisContext context, |
Source source, int offset, int length); |
} |
@@ -30,7 +30,7 @@ abstract class NavigationContributor { |
* |
* Clients are not expected to subtype this class. |
*/ |
-abstract class NavigationHolder { |
+abstract class NavigationCollector { |
/** |
* Record a new navigation region with the given [offset] and [length] that |
* should navigation to the given [targetLocation]. |
@@ -17,10 +17,10 @@ import 'package:analyzer/src/generated/source.dart' show Source; |
/** |
* Contribute navigation regions for a part of the given [source] into the |
- * given [holder]. The part is specified by the [offset] and [length]. |
+ * given [collector]. The part is specified by the [offset] and [length]. |
* The [context] can be used to get analysis results. |
*/ |